Chemistry Models (``taurex.chemistry``)
=======================================


Base
----

.. automodule:: taurex.data.profiles.chemistry.chemistry
   :members:
   :undoc-members:
   :show-inheritance:

Base (Auto)
-----------

.. automodule:: taurex.data.profiles.chemistry.autochemistry
   :members:
   :undoc-members:
   :show-inheritance:


Equilibrium Chemistry (ACE)
---------------------------

.. warning::
   This is no longer available in the base TauREx 3 since version 3.1.
   To use this you must install the ``taurex_ace`` plugin.

Free chemistry
--------------

.. automodule:: taurex.data.profiles.chemistry.taurexchemistry
   :members:
   :undoc-members:
   :show-inheritance:

Gas Models (``taurex.chemistry``)
=================================

Base
---------------------------------------------

.. automodule:: taurex.data.profiles.chemistry.gas.gas
   :members:
   :undoc-members:
   :show-inheritance:


Constant
-----------------------------------------------------

.. automodule:: taurex.data.profiles.chemistry.gas.constantgas
   :members:
   :undoc-members:
   :show-inheritance:


Two Layer
-----------------------------------------------------

.. automodule:: taurex.data.profiles.chemistry.gas.twolayergas
   :members:
   :undoc-members:
   :show-inheritance:

Array
-----------------------------------------------------

.. automodule:: taurex.data.profiles.chemistry.gas.twolayergas
   :members:
   :undoc-members:
   :show-inheritance:

